<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="sv" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Starta torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Hoppa över hashkontroll</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Skapa undermapp</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrenthanteringsläge:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Okategoriserad</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Lägg till kategori...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Ta bort kategori</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Ta bort oanvända kategorier</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Återuppta torrenter</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pausa torrenter</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Ta bort torrenter</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Redigera kategori...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Avsluta qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Endast en länk per rad</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Global gräns för sändningshastighet måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Global hämtningshastighetsgräns måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ gränser för sändningshastighet måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ hämtningshastighetsgräns måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maximalt aktiva hämtningar måste vara större än -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maximalt aktiva sändningar måste vara större än -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maximalt aktiva torrenter måste vara större än -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Gräns för maximalt antal anslutningar måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Gräns för maximalt antal anslutningar per torrent måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Gräns för maximalt antal sändningsplatser per torrent måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Kunde inte spara programinställningarna. qBittorrent är antagligen inte nåbar.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent på Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Gräns för delningsförhållandet måste vara mellan 0 och 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Distribuerings tidsgränsen måste vara mellan 0 och 525600 minuter.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Porten som användas för inkommande anslutningar måste vara mellan 1 och 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Porten som används för webbgränssnittet måste vara mellan 1 och 65535</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Kunde inte logga in. qBittorrent är troligtvis inte nåbart.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Felaktigt Användarnamn eller Lösenord</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Inloggning</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Ursprungliga upphovsmän</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Verkställ</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Skicka torrenter</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Spara filer till platsen:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Kaka:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Ange mapp här</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mer information</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Information om certifikat</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ange plats</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Begränsa sändningshastighet</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Begränsa hämtningshastighet</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Byt namn på torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Annan...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Måndag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Tisdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lördag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Söndag</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logga ut</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Hämta torrenter från deras webbadresser eller magnetlänkar</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Skicka lokal torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Är du säker på att du vill ta bort de markerade torrenterna från överföringslistan?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent-klienten är inte nåbar</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Globalt  antal sändningsplatser måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Ogiltigt kategorinamn:\nAnvänd inga specialtecken i kategorinamnet.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Det går inte att skapa kategori</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Sändningshastighetsgränsen måste vara större än 0 eller inaktiverad.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Ledigt diskutrymme: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrentinaktivitetstidtagare måste vara större än 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Spara hantering</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Hämtningshastighetsgränsen måste vara större än 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent har stängts av</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Alternativ...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Återuppta</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Lägsta prioritet</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Högsta prioritet</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Minska prioritet</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Höja prioritet</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Översta verktygsfältet</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusfält</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Hastighet i titelfältet</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Donera!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Återuppta alla</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pausa alla</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Lägg till torrentfil...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentation</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Lägg till torrentlänk...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Allmän hastighetsgräns för sändning</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Allmän hastighetsgräns för hämtning</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Är du säker på att du vill avsluta qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[N: %1/s, U: %2/s] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternativa hastighetsgränser</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Sökmotor</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrera torrentlista...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Överföringar</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Hämtningar</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Anslutning</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Webbgränssnitt</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Användargränsspråk:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>E-postavisering när hämtning slutförs</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Kör externa program när torrent slutförs</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-filtrering</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Schemalägg användning av alternativa hastighetsgränser</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrentkö</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Distribuera torrenter till deras distribueringstid når</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Lägg a&amp;utomatiskt till dessa bevakare till nya hämtningar:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Webbgränssnittet (fjärrstyrning)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-adress:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Serverdomäner:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Använd HTTPS istället för HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Kringgå autentisering för klienter på localhost</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Kringgå autentisering för klienter i vitlistade IP-subnät</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Uppdatera mitt dynamiska domännamn</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Behåll ofullständiga torrenter i:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopiera .torrent-filer till:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopiera .torrent-filer för färdiga hämtningar till:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Förallokera diskutrymme för alla filer</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Lägg till .!qB-ändelsen till ofullständiga filer</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Lägg automatiskt till torrenter från:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Den här servern kräver en säker anslutning (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentisering</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Användarnamn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Lösenord:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Aktiverat protokoll:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP och μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Lyssningsport</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port som används för inkommande anslutningar:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Använd UPnP / NAT-PMP-portomdirigering från min router</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Använd olika portar vid varje start</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Anslutningsgränser</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Högsta antal anslutningar per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Globalt högsta antal anslutningar:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maximalt antal sändningsplatser per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Allmänt maximalt antal sändningsplatser:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxyserver</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ingen)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Använd proxy för nodanslutningar</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Inaktivera anslutningar som inte stöds av proxyer</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Använd proxy endast för torrenter</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filtersökväg (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuellt bannlysta IP-adresser...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Tillämpa på bevakare</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globala hastighetsgränser</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Skickat:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Hämtning:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternativa hastighetsgränser</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Från:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Till:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>När:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Varje dag</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Vardagar</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Helger</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Inställningar för hastighetsgränser</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Tillämpa hastighetsgräns för transportoverhead</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Tillämpa hastighetsgräns för µTP-protokoll</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Sekretess</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Aktivera DHT (decentraliserat nätverk) för att hitta fler noder</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Aktivera nodutbyte (PeX) för att hitta fler noder</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Aktivera lokal nodidentifiering för att hitta fler noder</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Krypteringsläge:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Föredra kryptering</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Kräv kryptering</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Inaktivera kryptering</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Aktivera anonymt läge</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Högsta antal aktiva hämtningar:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maximala aktiva sändningar:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Högsta antal aktiva torrenter:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Räkna inte med långsamma torrenter i dessa begränsningar</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Delningsförhållandegräns</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Distribuera torrentfiler till deras förhållande når</translation>
    </message>
    <message>
        <source>then</source>
        <translation>sedan</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pausa dem</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Ta bort dem</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Använd UPnP / NAT-PMP för att vidarebefordra porten från min router</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certifikat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Nyckel:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrera</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domännamn:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Parametrar som stöds (skiftlägeskänslig):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentnamn</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategori</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Taggar (separerade med kommatecken)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Innehållssökväg (samma som root-sökväg för flerfilig torrent)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Root-sökväg (första torrentunderkatalogssökväg)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Sökväg för att spara</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Antal filer</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrentstorlek (byte)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Aktuell spårare</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tips: Inkapsla parametern med citattecken för att undvika att text skärs av vid blanktecknet (t. ex. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Webbanvändarnamnet måste vara minst 3 tecken långt.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Webbanvändarlösenordet måste vara minst 6 tecken långt.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Aktivera skydd för clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Aktivera Cross-Site Request Forgery (CSRF) skydd</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Radera .torrent-filer efteråt </translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Hämtningshastighetsgräns:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Sändningshastighetsgräns:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Ändra aktuellt lösenord</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Använd alternativt webbgränssnitt</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Standardsökväg för att spara:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Platsen för alternativa webbgränssnittsfiler kan inte vara tom.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Börja inte hämtning automatiskt</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Växla torrent till manuellt läge</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>När torrentkategorin ändras:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Flytta påverkade torrenter</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Tillämpa hastighetsgräns för noder på LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 betyder obegränsad</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Flytta torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>När standardsökvägen för att spara ändras:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Aktivera validering av värdrubrik</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Säkerhet</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>När kategorisökväg för att spara ändras:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Skapa undermapp för torrenter med flera filer</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Växla påverkade torrenter till manuellt läge</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Filplats:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuellt</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrentinaktivitetstidtagare:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Standard torrenthanteringsläge:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>När en torrent läggs till</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flaggor</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Anslutning</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Förlopp</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Hämtningshastighet</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Sändningshastighet</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Hämtat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Skickat</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Filer</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Land</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Hög</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximal</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Bevakare</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Noder</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-källor</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Innehåll</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Hämtat:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Överföring</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Tid aktiv:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Färdig om:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Skickat:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Distributörer:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Hämtningshastighet:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Sändningshastighet:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Noder:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Hämtningsgräns:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Sändningsgräns:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Spill:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Anslutningar:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Delningsförhållande:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Annonseras igen om:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Senast sedd fullständig:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Storlek totalt:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Delar:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Skapades av:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Lades till:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Slutfördes den:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Skapades den:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrenthash:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Sökväg för att spara:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldrig</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (har %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 denna session)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 max)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 totalt)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 genomsnitt)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Hämtningsgräns:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Sändningsgräns:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Övervakad mapp</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Åsidosatt spara plats</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Övervakad mapp</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Standard spara plats</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Användarstatistik</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Cache Statistik</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Läscache träffar: </translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Genomsnittlig kötid:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Anslutna noder:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Alla tiders delningsförhållande:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Alla tiders hämtning:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Sessionsspill:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Alla tiders sändning:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Total bufferstorlek:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Prestandastatistik</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Köade I/O-jobb: </translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Överbelastad skrivcache:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Överbelastad läscache:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Total köstorlek:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 noder</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Alla (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Hämtar (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Distribuerar (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Färdiga (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Återupptagen (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pausad (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktiva (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inaktiva (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Fallerade (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Alla (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Hämtar (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Distribuerar (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Färdiga (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pausad (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Återupptagna (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktiva (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inaktiva (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Fallerade (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Förlopp</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Hämtningsprioritet</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Återstår</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Tillgänglighet</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Storlek</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Slutfört</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Distributörer</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Noder</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Hämtningshastighet</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Sändningshastighet</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Förhållande</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Slutfört om</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Taggar</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Lades till</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Slutfördes den</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Bevakare</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Hämtningsgräns</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Sändningsgräns</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Hämtat</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Skickat</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Hämtat denna session</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Skickat denna session</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Återstår</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Tid aktiv</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Sökväg för att spara</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Färdig</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Förhållandegräns</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Senast sedd fullständig</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Senast aktivitet</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Storlek totalt</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Noder</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Meddelande</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Hämtat</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Bevakarwebbadress:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Uppdaterar...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Arbetar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Inaktiverad</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Inte ännu kontaktad</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Inga</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Distribueringar</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Fungerar inte</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopiera webbadress för bevakare</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Lägg till en ny bevakare...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Ändra bevakarwebbadress...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Redigera bevakare</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Reciprokörer</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Ta bort bevakare</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Lägg till bevakare</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista över bevakare att lägga till (en per rad):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 sedan</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Allokerar</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pausade</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Flyttar</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Distribuerar</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Distribuerar</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Köar</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Felaktiga</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Hämtar</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Hämtar metadata</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Kontrollerar</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Saknade filer</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Köar för kontroll</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Hämtar</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Kontrollerar återupptagningsdata</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Avstannad</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Hastighetsgräns för torrenthämtning</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Hastighetsgräns för torrentsändning</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Återuppta</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Tvinga återupptagning</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Begränsa delningsförhållande...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Begränsa sändningshastighet...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Begränsa hämtningshastighet...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Flytta uppåt</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Flytta nedåt</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Flytta överst</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Flytta nederst</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Ange plats...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopiera namn</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopiera hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Hämta första och sista delarna först</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatisk torrenthantering</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Ny...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Återställ</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritet</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Tvinga återkontroll</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopiera magnetlänk</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Superdistributionsläge</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Byt namn...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Hämta i sekventiell ordning</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Tvinga återkontroll</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Plats</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nytt namn</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ange plats</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Tvinga återannonsering</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Redigera kategori</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Sökväg för att spara</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Gränser för sändning/hämtning</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Använd global delningsgräns</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Ange ingen delningsgräns</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Ställ in delningsgräns till</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>förhållande</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>En avancerad BitTorrent-klient programmerad i C++, baserad på Qt-verktygslåda och libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Hemsida:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Felhantering:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Bekräftelse för borttagning</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Ta även bort filerna på hårddisken</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Bekräftelse för borttagning - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Hämta från webbadresser</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Hämta</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Lägg till torrentlänk...</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1 min</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1 min</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Sökväg för att spara är tom</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Insticksmodulsökväg:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>Webbadress eller lokal mapp</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Installera insticksmodul</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Distributörer:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Alla insticksmoduler</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Storlek:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stoppa</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Sök</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Sökinsticksmoduler...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Alla kategorier</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Sök i:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopiera beskrivningssidans webbadress</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Gå till beskrivningssidan</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultat (visar</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Hämta</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Endast torrentnamn</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Endast aktiverade</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>av</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Överallt</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Avinstallera</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Installera ny insticksmodul</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Du kan få nya sökmotorinsticksmoduler här:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Installerade sökningsinsticksmoduler:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiverad</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Varning: Var noga med att följa ditt lands upphovsrättslagar när du hämtar torrenter från någon av dessa sökmotorer.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Sök efter uppdateringar</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Sökinsticksmoduler</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Reciprokörer</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Sökmotor</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Distributörer</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Webbadress</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiverad</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
</context>
</TS>